@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2015-12-02'; # DATE
-our $VERSION = '1.42'; # VERSION
+our $DATE = '2015-12-30'; # DATE
+our $VERSION = '1.43'; # VERSION
 
 use 5.010001;
 use strict;
@@ -276,8 +276,7 @@ _
             my @profiles;
             for my $section (keys %{$r->{config}}) {
                 my %keyvals;
-                $section = '' if $section eq 'GLOBAL';
-                for my $word (split /\s+/, $section) {
+                for my $word (split /\s+/, ($section eq 'GLOBAL' ? '' : $section)) {
                     if ($word =~ /(.+)=(.*)/) {
                         $keyvals{$1} = $2;
                     } else {
@@ -490,7 +489,7 @@ sub do_completion {
     my ($words, $cword);
     if ($r->{shell} eq 'bash') {
         require Complete::Bash;
-        ($words, $cword) = @{ Complete::Bash::parse_cmdline() };
+        ($words, $cword) = @{ Complete::Bash::parse_cmdline(undef, undef, {truncate_current_word=>1}) };
     } elsif ($r->{shell} eq 'fish') {
         require Complete::Fish;
         ($words, $cword) = @{ Complete::Fish::parse_cmdline() };
@@ -1411,7 +1410,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.42 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-12-02.
+This document describes version 1.43 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-12-30.
 
 =head1 DESCRIPTION
 
